@@ -212,7 +212,6 @@ public class DAVConnection {
 
     public SVNLock doLock(String repositoryPath, String path, DAVRepository repos, String comment, boolean force, long revision) throws SVNException {
         beforeCall();
-        DAVBaselineInfo info = DAVUtil.getBaselineInfo(this, repos, path, -1, false, true, null);
 
         StringBuffer body = DAVLockHandler.generateSetLockRequest(null, comment);
         HTTPHeader header = new HTTPHeader();
@@ -711,7 +710,7 @@ public class DAVConnection {
         return myRepository;
     }
 
-    private void parseCapabilities(HTTPStatus status) {
+    protected void parseCapabilities(HTTPStatus status) {
         if (myCapabilities == null) {
             myCapabilities = new SVNHashMap();
         }
