@@ -29,6 +29,11 @@ public class SVNWCDbSelectMovedHereChildren extends SVNSqlJetSelectFieldsStateme
         return (String)(getRowValues().get(SVNWCDbSchema.NODES__Fields.moved_to.name()));
     }
 
+    @Override
+    protected Enum<?> getRowPathField() throws SVNException {
+        return SVNWCDbSchema.NODES__Fields.moved_to;
+    }
+
     @Override
     protected String getPathScope() {
         return (String)getBind(2);
