@@ -14,6 +14,7 @@ import org.tmatesoft.svn.core.wc.ISVNEventHandler;
 import org.tmatesoft.svn.core.wc.SVNEvent;
 import org.tmatesoft.svn.core.wc.SVNEventAction;
 import org.tmatesoft.svn.core.wc.SVNStatusType;
+import org.tmatesoft.svn.core.wc2.ISvnPatchHandler;
 import org.tmatesoft.svn.core.wc2.SvnScheduleForAddition;
 import org.tmatesoft.svn.core.wc2.SvnStatus;
 import org.tmatesoft.svn.util.SVNLogType;
@@ -133,11 +134,17 @@ public class SvnPatchTarget extends SvnTargetContent {
         this.rejectStream = rejectStream;
     }
 
-    public static SvnPatchTarget applyPatch(SvnPatch patch, File workingCopyDirectory, int stripCount, SVNWCContext context, boolean ignoreWhitespace, boolean removeTempFiles) throws SVNException, IOException {
+    public static SvnPatchTarget applyPatch(SvnPatch patch, File workingCopyDirectory, int stripCount, SVNWCContext context, boolean ignoreWhitespace, boolean removeTempFiles, ISvnPatchHandler patchHandler) throws SVNException, IOException {
         SvnPatchTarget target = initPatchTarget(patch, workingCopyDirectory, stripCount, removeTempFiles, context);
         if (target.isSkipped()) {
             return target;
         }
+        if (patchHandler != null) {
+            final boolean filtered = patchHandler.singlePatch(target.getCanonPathFromPatchfile(), target.getPatchedAbsPath(), target.getRejectAbsPath());
+            if (filtered) {
+                return target;
+            }
+        }
         List<SvnDiffHunk> hunks = patch.getHunks();
         for (SvnDiffHunk hunk : hunks) {
             SvnHunkInfo hunkInfo;
@@ -648,7 +655,7 @@ public class SvnPatchTarget extends SvnTargetContent {
 
         SvnStatus status;
         try {
-            status = SVNStatusEditor17.internalStatus(context, getAbsPath());
+            status = SVNStatusEditor17.internalStatus(context, getAbsPath(), true);
 
             if (status.getNodeStatus() == SVNStatusType.STATUS_IGNORED ||
                     status.getNodeStatus() == SVNStatusType.STATUS_UNVERSIONED ||
@@ -753,7 +760,7 @@ public class SvnPatchTarget extends SvnTargetContent {
             if (isAdded() || isReplaced()) {
                 File parentAbsPath = SVNFileUtil.getParentFile(getAbsPath());
 
-                SVNNodeKind parentDbKind = context.readKind(parentAbsPath, false);
+                SVNNodeKind parentDbKind = context.readKind(parentAbsPath, false, false);
 
                 if (parentDbKind == SVNNodeKind.DIR || parentDbKind == SVNNodeKind.FILE) {
                     if (parentDbKind != SVNNodeKind.DIR) {
@@ -767,7 +774,7 @@ public class SvnPatchTarget extends SvnTargetContent {
                     createMissingParents(workingCopyDirectory, context, dryRun);
                 }
             } else {
-                SVNNodeKind wcKind = context.readKind(getAbsPath(), false);
+                SVNNodeKind wcKind = context.readKind(getAbsPath(), false, false);
 
                 if (getKindOnDisk() == SVNNodeKind.NONE || wcKind != getKindOnDisk()) {
                     setSkipped(true);
@@ -827,7 +834,7 @@ public class SvnPatchTarget extends SvnTargetContent {
 
         for (String component : components) {
             localAbsPath = SVNFileUtil.createFilePath(localAbsPath, component);
-            SVNNodeKind wcKind = context.readKind(localAbsPath, true);
+            SVNNodeKind wcKind = context.readKind(localAbsPath, false, true);
 
             SVNNodeKind diskKind = SVNFileType.getNodeKind(SVNFileType.getType(localAbsPath));
             if (diskKind == SVNNodeKind.FILE || wcKind == SVNNodeKind.FILE) {
